CounterAttrDecremented class

Change representing a counter attribute on a referenced entity being decremented.

Decreases a numeric attribute associated with an entity reference, useful for tracking reductions in quantities or counts.

Inheritance

Constructors

CounterAttrDecremented({required EntityId attrId, required String attrName, required int by})
Creates a counter attribute decrement change.
CounterAttrDecremented.fromJson(Map<String, dynamic> json)
factory

Properties

attrId String
ID of the entity that owns this attribute.
final
attrName String
Name of the attribute being changed.
final
by int
Amount to decrement the counter attribute by.
final
hashCode int
The hash code for this object.
no setterinherited
isOverwriting bool
Whether changes of this type overwrite or accumulate.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

format() String
Returns a formatted string representation of the message content.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts the message to a JSON representation for network transmission.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited