CounterViewChange class abstract

Base class for changes to counter views.

Counter view changes accumulate rather than overwrite, allowing multiple increments, decrements, and resets to be applied in sequence.

Inheritance
Implementers

Constructors

CounterViewChange()

Properties

hashCode int
The hash code for this object.
no setterinherited
isOverwriting bool
Whether changes of this type overwrite or accumulate.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

format() String
Returns a formatted string representation of the message content.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts the message to a JSON representation for network transmission.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited