CounterViewIncremented class

Change representing an increment operation on a counter view.

Adds the specified amount to the current counter value.

Inheritance

Constructors

CounterViewIncremented({required int by})
Creates a counter increment change.
CounterViewIncremented.fromJson(Map<String, dynamic> json)
factory

Properties

by int
Amount to increment the counter by (can be negative for decrement).
final
hashCode int
The hash code for this object.
no setterinherited
isOverwriting bool
Whether changes of this type overwrite or accumulate.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

format() String
Returns a formatted string representation of the message content.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts the message to a JSON representation for network transmission.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited