CounterViewReset class

Change representing a reset operation on a counter view.

Sets the counter to a specific value, discarding the previous count.

Inheritance

Constructors

CounterViewReset({required int newValue})
Creates a counter reset change.
CounterViewReset.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isOverwriting bool
Whether changes of this type overwrite or accumulate.
no setterinherited
newValue int
The new value to set the counter to.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

format() String
Returns a formatted string representation of the message content.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts the message to a JSON representation for network transmission.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited