QueryResultBuilder class

Builder for constructing QueryResult objects programmatically.

Enables building complex query results with multiple view results for testing, mocking, or programmatic result construction.

Available extensions

Constructors

QueryResultBuilder()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

add(ViewQueryResultBuilder b) → void
Adds a view query result builder to this query result.
build() QueryResult
list(String name, Map<RefIdNamePair, dynamic> attrs, String changeId, String pageId, void fun(Map<double, ({QueryResultBuilder query, EntityId refId})> items)) → void

Available on QueryResultBuilder, provided by the QueryResultBuilderManual extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
ref(String name, EntityId value, Map<String, dynamic> attrs, String changeId, void fun(QueryResultBuilder rb)) → void

Available on QueryResultBuilder, provided by the QueryResultBuilderManual extension

toString() String
A string representation of this object.
inherited
val(String name, dynamic value, String changeId) → void

Available on QueryResultBuilder, provided by the QueryResultBuilderManual extension

Operators

operator ==(Object other) bool
The equality operator.
inherited